netapp_ontap.models.s3_service_user_post API documentation
Description: Copyright &copy; 2026 NetApp Inc. All rights reserved …

# Module `netapp_ontap.models.s3_service_user_post`

Copyright © 2026 NetApp Inc. All rights reserved.

This file has been automatically generated based on the ONTAP REST API documentation.

## Classes

`class S3ServiceUserPostSchema (*, only: types.StrSequenceOrSet | None = None, exclude: types.StrSequenceOrSet = (), many: bool | None = None, context: dict | None = None, load_only: types.StrSequenceOrSet = (), dump_only: types.StrSequenceOrSet = (), partial: bool | types.StrSequenceOrSet | None = None, unknown: str | None = None)`

  The fields of the S3ServiceUserPost object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC
  - abc.ABC

  ### Class variables

  `access_key: str GET`

    Specifies the access key for the user.

    Example:

  `key_expiry_time: ImpreciseDateTime GET`

    Specifies the date and time after which the keys expire and are no longer valid.

    Example: 2024-01-01T00:00:00.000+0000

  `links: CollectionLinks GET`

    The links field of the s3_service_user_post.

  `name: str GET`

    The name of the user.

    Example: user-1

  `secret_key: str GET`

    Specifies the secret key for the user.

    Example: